@@ -11,9 +11,9 @@ COUNT_CACHE = TTLCache(maxsize=500, ttl=300)
 @cached(COUNT_CACHE)
 def count_for(fn, filter_str):
     counts = {}
-    filter = filter_str.split(',')
+    filt = filter_str.split(',')
     for rec in DataIterator(fn):
-        if rec.featuretype not in filter:
+        if rec.featuretype not in filt:
             continue
         if rec.featuretype not in counts:
             counts[rec.featuretype] = 0
@@ -22,6 +22,9 @@ def count_for(fn, filter_str):
 
 
 class Sequence():
+    """Exemplar class to extract summary data for assembly sequences.
+    """
+
     def __init__(self, assembly_report, fasta, gff3):
         self._assembly_report = assembly_report
         self._fasta = fasta
@@ -40,10 +43,9 @@ class Sequence():
         ]
 
     def report(self):
-
-        logger.debug(f'Scan {self._gff3} for gene count')
+        logger.debug('Scan %s for gene count', self._gff3)
         gene_count = count_for(self._gff3, 'gene')
-        logger.debug(f'Gene: {gene_count}')
+        logger.debug('Gene: %d', gene_count)
         return [
             self._assembly_report.assembly_info.refseq_assm_acc,
             f'...{self._assembly_report.assembly_info.description[-30:]}',
